coimealta
=========

A keeper (coimealta in Irish) for personal and household information.

I decided I needed to organize my household stuff and my contacts
information, and went for a simple CSV-based system; a proper database
would have been overkill, and would have been less convenient for data
entry and editing.

There are two parts to the software, in separate directories:
*inventory*, and *contacts*.

It's for keeping my information, and I named it after Sliabh Coimeálta
(Keeper Hill) in Ireland, which I used to live near.

